@@ -1,4 +1,4 @@
 #!/bin/bash
 
-isu_pid=$(pidof Isu)
+isu_pid=$(pidof isu)
 timeout 60 tail --pid=$isu_pid -f /dev/null
