@@ -59,7 +59,6 @@ class SMTLinkTest extends SMTServiceHelper
     const LINK_UTF8_NAME_MAX_SIZE = 80; //80 chars=> 320 bytes max
     const TIME_SLOT_NONE = "NONE";
     const STOP = "STOP";
-    const SEQUENTIAL = "SEQU";
     const RANDOM = "RAND";
     const SLEEP_TIME_FOR_TEST_REMOVAL_S = 5;//sleep 5s
     const LOCK_TEST_SETUP_FILE = "/../../../tmp/testSetup.lock";
@@ -1682,7 +1681,7 @@ class SMTLinkTest extends SMTServiceHelper
      */
     function setSequensorOn()
     {
-        $this->send( SMTOtuApi::setMonitoringSequensorStatus( self::SEQUENTIAL ) );
+        $this->send( SMTOtuApi::setMonitoringSequensorStatus( SMTOtuApi::SEQUENTIAL ) );
     }    
     
     /**
