@@ -16,6 +16,6 @@ init_obb7000_init()
     GPIO_NUMBER=${GPIO_CHIP:8}
 	echo 1 > /sys/class/gpio/gpio${GPIO_NUMBER}/value
 
-	# Set mode to 0x04 as it is required for communicating with internal and external switches
-	/usr/bin/hamma action.write port.moduleSelector.MODULE_SEL value.0x04
+	# Set mode to "ENIGPIO" as it is required for communicating with internal and external switches
+	echo "ENIGPIO" > /sys/platform/module_selector/slotA
 }
